@@ -19,11 +19,10 @@
 """Docplates commandline entry point."""
 
 import sys
-from typing import List
 
 from .cmdline import main
 
-__all__: List[str] = []
+__all__: list[str] = []
 
 
 if __name__ == "__main__":
