@@ -27,7 +27,6 @@ import os
 import pathlib
 import shutil
 import tempfile
-from typing import List
 
 import jinja2.exceptions
 import pytest
@@ -36,7 +35,7 @@ import docplates
 
 from ..base import BaseTest
 
-__all__: List[str] = []
+__all__: list[str] = []
 
 
 class TestLoadAddonViaPath(BaseTest):
